package com.jeeplus.test.workClientInfo.controller;

import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.jeeplus.sys.utils.StringUtils;
import com.jeeplus.test.projectRecords.domain.Project;
import com.jeeplus.test.workClientInfo.domain.WorkClientInfo;
import com.jeeplus.test.workClientInfo.domain.dto.PageInfoDto;
import com.jeeplus.test.workClientInfo.domain.dto.WorkClientInfosDto;
import com.jeeplus.test.workClientInfo.service.WorkClientService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.List;

@Slf4j
@Api(tags ="workClientInfo")
@RestController
@RequestMapping(value = "/workClientInfo/workClientInfo")
public class WorkClientController {

    @Resource
    private WorkClientService workClientService;

    /**
     * 客户信息列表
     */
    @ApiOperation(value = "客户信息列表")
    @PostMapping(value = "list")
    public Page<WorkClientInfo> list(@RequestBody PageInfoDto pageInfoDto, Page<WorkClientInfo> page) {
        return workClientService.list(pageInfoDto, page);
    }

    /**
     * 客户信息新增/修改
     */
    @ApiOperation(value = "客户信息新增/修改")
    @PostMapping(value = "save")
    public ResponseEntity save(@RequestBody WorkClientInfosDto workClientInfosDto) {
        if(ObjectUtil.isNotEmpty(workClientInfosDto)){
            if(ObjectUtil.isNotEmpty(workClientInfosDto.getWorkClientInfo())){
                if(StrUtil.isNotEmpty(workClientInfosDto.getWorkClientInfo().getId())){
                    return ResponseEntity.ok(workClientService.update(workClientInfosDto));
                }else{
                    return ResponseEntity.ok(workClientService.save(workClientInfosDto));
                }
            }else{
                return ResponseEntity.badRequest().body("保存信息失败，没有获取到数据");
            }
        }
        return ResponseEntity.badRequest().body("保存信息失败，没有获取到数据");
    }

    /**
     * 客户信息删除
     */
    @ApiOperation(value = "客户信息删除")
    @GetMapping(value = "remove")
    public String remove(@RequestParam String id) {
        return workClientService.removeById(id);
    }

    /**
     * 客户信息查询
     */
    @ApiOperation(value = "客户信息查询")
    @GetMapping(value = "findById")
    public WorkClientInfosDto findById(@RequestParam String id) {
        return workClientService.findById(id);
    }

    /**
     * 客户信息更新
     */
    @ApiOperation(value = "客户信息更新")
    @PostMapping(value = "update")
    public String update(@RequestBody WorkClientInfosDto workClientInfosDto) {
        return workClientService.update(workClientInfosDto);
    }

    /**
     * 根据名称模糊搜索客户信息
     */
    @ApiOperation(value = "根据名称模糊搜索客户信息")
    @GetMapping(value = "findListByName")
    public List<WorkClientInfo> findListByName(@RequestParam String name) {
        return workClientService.findListByName(name);
    }
}
